pub enum TensorError {
ShapeMismatch {
operation: String,
left: Vec<usize>,
right: Vec<usize>,
},
InvalidShape {
shape: Vec<usize>,
expected: usize,
actual: usize,
},
EmptyInput {
operation: String,
},
Operation {
operation: String,
source: BoxedError,
},
}Expand description
Reason a tensor operation failed.
Variants
ShapeMismatch
Two operands do not have compatible shapes.
Fields
InvalidShape
Flat data does not contain the number of elements required by its shape.
Fields
EmptyInput
An operation requires at least one input element or tensor.
Operation
A tensor backend could not execute an operation.
Fields

source: BoxedErrorUnderlying backend error.
Implementations