pub struct OnPolicyRuntime<A: Agent, S: Sampler> {
pub agent: A,
pub sampler: S,
}Expand description
Coupled runtime unit that binds an agent and sampler together.
Fields
agent: ATrainable agent.
sampler: SRollout collector.
Implementations
Sourceimpl<A: Agent, S: Sampler> OnPolicyRuntime<A, S>
impl<A: Agent, S: Sampler> OnPolicyRuntime<A, S>
Sourcepub fn collect(&mut self) -> Result<(), Error>
pub fn collect(&mut self) -> Result<(), Error>
Collects a fresh set of rollouts using the sampler-facing actor.
Errors
Returns an error if the sampler cannot collect the rollouts.
Sourcepub fn trajectory_containers(
&mut self,
) -> impl AsRef<[TrajectoryView<'_, S::Tensor>]>
pub fn trajectory_containers( &mut self, ) -> impl AsRef<[TrajectoryView<'_, S::Tensor>]>
Returns the last collected trajectory containers from the sampler.