OnPolicyAlgorithmHooks

Trait OnPolicyAlgorithmHooks 

pub trait OnPolicyAlgorithmHooks {
    type A: Agent;
    type S: Sampler;

    // Required methods
    fn init_hook(
        &mut self,
        runtime: &mut OnPolicyRuntime<Self::A, Self::S>,
    ) -> HookResult;
    fn post_rollout_hook(
        &mut self,
        runtime: &mut OnPolicyRuntime<Self::A, Self::S>,
    ) -> HookResult;
    fn post_training_hook(
        &mut self,
        runtime: &mut OnPolicyRuntime<Self::A, Self::S>,
    ) -> HookResult;
    fn finish_training_hook(
        &mut self,
        runtime: &mut OnPolicyRuntime<Self::A, Self::S>,
    ) -> Result<(), Error>;
}
Lifecycle hooks that control an OnPolicyAlgorithm training loop.

Required Associated Types

type A: Agent

Agent type controlled by the training loop.

type S: Sampler

Sampler type controlled by the training loop.

Required Methods

fn init_hook( &mut self, runtime: &mut OnPolicyRuntime<Self::A, Self::S>, ) -> HookResult

Called once before rollout/training starts.

fn post_rollout_hook( &mut self, runtime: &mut OnPolicyRuntime<Self::A, Self::S>, ) -> HookResult

Called after rollouts are collected and before agent learning.

fn post_training_hook( &mut self, runtime: &mut OnPolicyRuntime<Self::A, Self::S>, ) -> HookResult

Called after the agent has learned from the latest rollouts.

fn finish_training_hook( &mut self, runtime: &mut OnPolicyRuntime<Self::A, Self::S>, ) -> Result<(), Error>

Called once when the loop exits.

Errors

Returns an error if end-of-training finalization fails.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors